About BioSimulators-COPASI — BioSimulators-COPASI 0.1.33 documentation

# About BioSimulators-COPASI

## License

This package is released under the MIT License. COPASI is released under the Artistic 2.0 License.

## Development team

This package was developed by the Karr Lab at the Icahn School of Medicine at Mount Sinai and the Center for Cell Analysis & Modeling at the University of Connecticut as part of the Center for Reproducible Biomedical Modeling. COPASI was developed by a team at the University of Connecticut, the University of Heidelberg, and the University of Virginia.

## Questions and comments

Please contact the BioSimulators Team with any questions or comments about the command-line program or Docker image. Please contact the COPASI Team with any questions or comments about COPASI.